=== modified file 'drizzled/diagnostics_area.h'
--- drizzled/diagnostics_area.h	2011-03-15 20:03:35 +0000
+++ drizzled/diagnostics_area.h	2011-03-22 09:36:03 +0000
@@ -21,6 +21,8 @@
 
 #include <drizzled/base.h>
 #include <drizzled/error_t.h>
+#include <drizzled/sql_error.h>
+#include <drizzled/sql_list.h>
 
 namespace drizzled {
 
@@ -78,6 +80,8 @@
   uint64_t last_insert_id() const;
   uint32_t total_warn_count() const;
 
+  List<DRIZZLE_ERROR> m_warn_list;
+
   Diagnostics_area() { reset_diagnostics_area(); }
 
 private:
@@ -127,7 +131,7 @@
   enum_diagnostics_status m_status;
   /**
     @todo: the following Session members belong here:
-    - warn_list, warn_count,
+    - warn_count,
   */
 };
 

=== modified file 'drizzled/session.cc'
--- drizzled/session.cc	2011-03-22 09:05:35 +0000
+++ drizzled/session.cc	2011-03-22 09:36:03 +0000
@@ -263,7 +263,6 @@
   open_options=ha_open_options;
   update_lock_default= TL_WRITE;
   session_tx_isolation= (enum_tx_isolation) variables.tx_isolation;
-  warn_list.clear();
   memset(warn_count, 0, sizeof(warn_count));
   memset(&status_var, 0, sizeof(status_var));
 

=== modified file 'drizzled/session.h'
--- drizzled/session.h	2011-03-22 00:40:14 +0000
+++ drizzled/session.h	2011-03-22 09:36:03 +0000
@@ -577,7 +577,6 @@
     class. With current implementation warnings produced in each prepared
     statement/cursor settle here.
   */
-  List<DRIZZLE_ERROR> warn_list;
   uint32_t warn_count[(uint32_t) DRIZZLE_ERROR::WARN_LEVEL_END];
   uint32_t total_warn_count;
 

=== modified file 'drizzled/sql_error.cc'
--- drizzled/sql_error.cc	2011-03-21 18:32:26 +0000
+++ drizzled/sql_error.cc	2011-03-22 09:36:03 +0000
@@ -53,6 +53,7 @@
 #include <drizzled/plugin/client.h>
 #include <drizzled/sql_lex.h>
 #include <drizzled/system_variables.h>
+#include <drizzled/diagnostics_area.h>
 
 using namespace std;
 
@@ -92,7 +93,7 @@
     memset(session->warn_count, 0, sizeof(session->warn_count));
     if (force)
       session->total_warn_count= 0;
-    session->warn_list.clear();
+    session->main_da().m_warn_list.clear();
     session->row_count= 1; // by default point to row 1
   }
 }
@@ -145,11 +146,11 @@
     return NULL;
 
   DRIZZLE_ERROR *err= NULL;
-  if (session->warn_list.size() < session->variables.max_error_count)
+  if (session->main_da().m_warn_list.size() < session->variables.max_error_count)
   {
     /* We have to use warn_root, as mem_root is freed after each query */
     err= new (&session->warn_root) DRIZZLE_ERROR(session, code, level, msg);
-    session->warn_list.push_back(err, &session->warn_root);
+    session->main_da().m_warn_list.push_back(err, &session->warn_root);
   }
   session->warn_count[(uint32_t) level]++;
   session->total_warn_count++;
@@ -223,7 +224,7 @@
 
   unit->set_limit(sel);
 
-  List<DRIZZLE_ERROR>::iterator it(session->warn_list.begin());
+  List<DRIZZLE_ERROR>::iterator it(session->main_da().m_warn_list.begin());
   while (DRIZZLE_ERROR* err= it++)
   {
     /* Skip levels that the user is not interested in */

=== modified file 'drizzled/sql_table.cc'
--- drizzled/sql_table.cc	2011-03-21 18:32:26 +0000
+++ drizzled/sql_table.cc	2011-03-22 09:36:03 +0000
@@ -44,6 +44,7 @@
 #include <drizzled/pthread_globals.h>
 #include <drizzled/typelib.h>
 #include <drizzled/plugin/storage_engine.h>
+#include <drizzled/diagnostics_area.h>
 
 #include <algorithm>
 #include <sstream>
@@ -1809,7 +1810,7 @@
     */
     if (!table->table)
     {
-      if (!session->warn_list.size())
+      if (!session->main_da().m_warn_list.size())
         push_warning(session, DRIZZLE_ERROR::WARN_LEVEL_ERROR,
                      ER_CHECK_NO_SUCH_TABLE, ER(ER_CHECK_NO_SUCH_TABLE));
       result_code= HA_ADMIN_CORRUPT;
@@ -1858,7 +1859,7 @@
     session->lex().cleanup_after_one_table_open();
     session->clear_error();  // these errors shouldn't get client
     {
-      List<DRIZZLE_ERROR>::iterator it(session->warn_list.begin());
+      List<DRIZZLE_ERROR>::iterator it(session->main_da().m_warn_list.begin());
       DRIZZLE_ERROR *err;
       while ((err= it++))
       {

